//
//  SingleTapMenuView.m
//  SingleTapMenu
//
//  Created by Sean Kladek on 5/25/12.
//  Copyright (c) 2012 The Nerdery. All rights reserved.
//

#import "SingleTapMenuView.h"

@interface SingleTapMenuView ()

- (void)viewTapped:(UITapGestureRecognizer *)gesture;

@end

@implementation SingleTapMenuView
@synthesize menuItems = _menuItems;

- (id)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        
        //Initialize setup to the view
        self.backgroundColor = [UIColor grayColor];
        
        //Add a gesture recognizer to the view
        UITapGestureRecognizer *tapGesture = [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(viewTapped:)];
        [self addGestureRecognizer:tapGesture];
    }
    return self;
}

- (void)viewTapped:(UITapGestureRecognizer *)gesture
{
    //Sets the tapped object as the first responder
    [self becomeFirstResponder];
    
    //Access the stock shared menu controller
    UIMenuController *menuController = [UIMenuController sharedMenuController];
    
    //Set the controller's menu items to the menu items array
    [menuController setMenuItems:_menuItems];
    
    //Set the menu's target rect and view
    [menuController setTargetRect:CGRectMake((self.frame.size.width / 2), 0, 0, 0) inView:self];
    
    //Check to see if the menu is currently displayed
    if (![menuController isMenuVisible]) {
        //Display the menu with fade-in animation
        [menuController setMenuVisible:YES animated:YES];
    }
}

- (BOOL)canBecomeFirstResponder
{
    return YES;
}

@end
